@@ -7,7 +7,7 @@ use Text::Tradition::Stemma;
 use Text::Tradition::Witness;
 
 use vars qw( $VERSION );
-$VERSION = "0.1";
+$VERSION = "0.2";
 
 has 'collation' => (
     is => 'ro',
@@ -34,11 +34,16 @@ has 'name' => (
     default => 'Tradition',
     );
     
+has 'language' => (
+	is => 'ro',
+	isa => 'Str',
+	);
+    
 has 'stemmata' => (
 	traits => ['Array'],
 	isa => 'ArrayRef[Text::Tradition::Stemma]',
 	handles => {
-		all_stemmata => 'elements',
+		stemmata => 'elements',
 		_add_stemma => 'push',
 		stemma => 'get',
 		stemma_count => 'count',
